@@ -9,7 +9,7 @@ https://raw.github.com/bengillies/chrjs.store/master/dist/chrjs-store-latest.js
  *
  * Dependencies: chrjs library, jQuery, TiddlySpace
  *
- * Version: 0.4.3
+ * Version: 0.4.4
  *
  * created by Ben Gillies
  * Chrjs-Store is distributed under a BSD License
@@ -195,7 +195,8 @@ var states = {
 		action: splitInner(1, Regexps.whitespace),
 		tiddlerTest: function(value) {
 			return function(tiddler) {
-				return (~tiddler.tags.indexOf(value)) ? true : false;
+				return (tiddler.tags && ~tiddler.tags.indexOf(value)) ?
+					true : false;
 			};
 		}
 	},
@@ -254,7 +255,8 @@ var states = {
 		action: splitInner(1, Regexps.doubleQuote),
 		tiddlerTest: function(value) {
 			return function(tiddler) {
-				return (~tiddler.text.indexOf(value)) ? true : false;
+				return (tiddler.text && ~tiddler.text.indexOf(value)) ?
+					true : false;
 			};
 		}
 	},
@@ -989,7 +991,7 @@ return function(container) {
 			(container instanceof tiddlyweb.Bag)) {
 		defaultContainer = {
 			pullFrom: container,
-			pushTo: Container
+			pushTo: container
 		};
 	} else if (container) {
 		defaultContainer = {
@@ -1050,7 +1052,7 @@ return function(container) {
 
 		if (defaultContainer) {
 			return returnContainer(defaultContainer);
-		} else {
+		} else if (callbackQueue.length === 0) {
 			determineContainer(function(container) {
 				defaultContainer = container;
 				returnContainer(container);
